/*
 * Note: this file originally auto-generated by mib2c using
 *       version : 14170 $ of $ 
 *
 * $Id:$
 */
/** \page MFD helper for dessertSysifTable
 *
 * \section intro Introduction
 * Introductory text.
 *
 */
/*
 * standard Net-SNMP includes 
 */
#include <net-snmp/net-snmp-config.h>
#include <net-snmp/net-snmp-includes.h>
#include <net-snmp/agent/net-snmp-agent-includes.h>

/*
 * include our parent header 
 */
#include "dessertSysifTable.h"

#include <net-snmp/agent/mib_modules.h>

#include "dessertSysifTable_interface.h"

oid             dessertSysifTable_oid[] = { DESSERTSYSIFTABLE_OID };

int             dessertSysifTable_oid_size =
OID_LENGTH(dessertSysifTable_oid);

dessertSysifTable_registration dessertSysifTable_user_context;

void            initialize_table_dessertSysifTable(void);
void            shutdown_table_dessertSysifTable(void);


/**
 * Initializes the dessertSysifTable module
 */
void
init_dessertSysifTable(void)
{
    DEBUGMSGTL(("verbose:dessertSysifTable:init_dessertSysifTable",
                "called\n"));

    /*
     * TODO:300:o: Perform dessertSysifTable one-time module initialization.
     */

    /*
     * here we initialize all the tables we're planning on supporting
     */
    if (should_init("dessertSysifTable"))
        initialize_table_dessertSysifTable();

}                               /* init_dessertSysifTable */

/**
 * Shut-down the dessertSysifTable module (agent is exiting)
 */
void
shutdown_dessertSysifTable(void)
{
    if (should_init("dessertSysifTable"))
        shutdown_table_dessertSysifTable();

}

/**
 * Initialize the table dessertSysifTable 
 *    (Define its contents and how it's structured)
 */
void
initialize_table_dessertSysifTable(void)
{
    dessertSysifTable_registration *user_context;
    u_long          flags;

    DEBUGMSGTL(("verbose:dessertSysifTable:initialize_table_dessertSysifTable", "called\n"));

    /*
     * TODO:301:o: Perform dessertSysifTable one-time table initialization.
     */

    /*
     * TODO:302:o: |->Initialize dessertSysifTable user context
     * if you'd like to pass in a pointer to some data for this
     * table, allocate or set it up here.
     */
    /*
     * a netsnmp_data_list is a simple way to store void pointers. A simple
     * string token is used to add, find or remove pointers.
     */
    user_context =
        netsnmp_create_data_list("dessertSysifTable", NULL, NULL);

    /*
     * No support for any flags yet, but in the future you would
     * set any flags here.
     */
    flags = 0;

    /*
     * call interface initialization code
     */
    _dessertSysifTable_initialize_interface(user_context, flags);
}                               /* initialize_table_dessertSysifTable */

/**
 * Shutdown the table dessertSysifTable 
 */
void
shutdown_table_dessertSysifTable(void)
{
    /*
     * call interface shutdown code
     */
    _dessertSysifTable_shutdown_interface(&dessertSysifTable_user_context);
}

/**
 * extra context initialization (eg default values)
 *
 * @param rowreq_ctx    : row request context
 * @param user_init_ctx : void pointer for user (parameter to rowreq_ctx_allocate)
 *
 * @retval MFD_SUCCESS  : no errors
 * @retval MFD_ERROR    : error (context allocate will fail)
 */
int
dessertSysifTable_rowreq_ctx_init(dessertSysifTable_rowreq_ctx *
                                  rowreq_ctx, void *user_init_ctx)
{
    DEBUGMSGTL(("verbose:dessertSysifTable:dessertSysifTable_rowreq_ctx_init", "called\n"));

    netsnmp_assert(NULL != rowreq_ctx);

    /*
     * TODO:210:o: |-> Perform extra dessertSysifTable rowreq initialization. (eg DEFVALS)
     */

    return MFD_SUCCESS;
}                               /* dessertSysifTable_rowreq_ctx_init */

/**
 * extra context cleanup
 *
 */
void
dessertSysifTable_rowreq_ctx_cleanup(dessertSysifTable_rowreq_ctx *
                                     rowreq_ctx)
{
    DEBUGMSGTL(("verbose:dessertSysifTable:dessertSysifTable_rowreq_ctx_cleanup", "called\n"));

    netsnmp_assert(NULL != rowreq_ctx);

    /*
     * TODO:211:o: |-> Perform extra dessertSysifTable rowreq cleanup.
     */
}                               /* dessertSysifTable_rowreq_ctx_cleanup */

/**
 * pre-request callback
 *
 *
 * @retval MFD_SUCCESS              : success.
 * @retval MFD_ERROR                : other error
 */
int
dessertSysifTable_pre_request(dessertSysifTable_registration *
                              user_context)
{
    DEBUGMSGTL(("verbose:dessertSysifTable:dessertSysifTable_pre_request",
                "called\n"));

    /*
     * TODO:510:o: Perform dessertSysifTable pre-request actions.
     */

    return MFD_SUCCESS;
}                               /* dessertSysifTable_pre_request */

/**
 * post-request callback
 *
 * Note:
 *   New rows have been inserted into the container, and
 *   deleted rows have been removed from the container and
 *   released.
 *
 * @param user_context
 * @param rc : MFD_SUCCESS if all requests succeeded
 *
 * @retval MFD_SUCCESS : success.
 * @retval MFD_ERROR   : other error (ignored)
 */
int
dessertSysifTable_post_request(dessertSysifTable_registration *
                               user_context, int rc)
{
    DEBUGMSGTL(("verbose:dessertSysifTable:dessertSysifTable_post_request",
                "called\n"));

    /*
     * TODO:511:o: Perform dessertSysifTable post-request actions.
     */

    return MFD_SUCCESS;
}                               /* dessertSysifTable_post_request */


/** @{ */
